import socket
import requests



def sondarip(ip=None ,* ,mostrar_flag=False):
	
	whois = "https://ipwho.is/"
	
	if ip is None:
		requisicao = requests.get(whois).json()
	else:
		ip = ip.strip()
		requisicao = requests.get(f"{whois}{ip}").json()
	
	if not mostrar_flag:
		requisicao.pop('flag', None)
	
	return requisicao
	
	
	
def pediripsite(host):
	
	host = host.strip()
	host = host.replace('https://www.', '')
	host = host.replace('http://www.', '')
	host = host.replace('www.', '')
	
	ip = socket.gethostbyname(host)
	
	return ip
	



from setuptools import setup, find_packages

with open("README.md", "r") as f:
    page_description = f.read()

#with open("requirements.txt", "r") as f:
#    requirements = f.read().splitlines()

setup(
    name="escrutinar_jp",
    version="0.0.1",
    author="Jorge Paulo",
    author_email="jorgepsan7@gmail.com",
    description="pegar o IP de um determinado site, coletar dados de um determinado IP.",
    long_description=page_description,
    long_description_content_type="text/markdown",
    url="https://github.com/JP-Linux/projeto_escrutinar",
    packages=find_packages(),
    install_requires="requests",
    python_requires='>=3.7',
)
